@@ -13,24 +13,23 @@
 #include "inputmethod.h"
 #include "platform.h"
 #include "pluginmanager.h"
+#include "utils/xcbutils.h"
 #include "wayland_server.h"
 #include "workspace.h"
-#include "utils/xcbutils.h"
-#include "xwl/xwayland.h"
+#include "xwayland/xwayland.h"
 
 #include <KPluginMetaData>
 
 #include <QAbstractEventDispatcher>
 #include <QPluginLoader>
 #include <QSocketNotifier>
-#include <QStyle>
 #include <QThread>
 #include <QtConcurrentRun>
 
 // system
-#include <unistd.h>
-#include <sys/socket.h>
 #include <iostream>
+#include <sys/socket.h>
+#include <unistd.h>
 
 Q_IMPORT_PLUGIN(KWinIntegrationPlugin)
 Q_IMPORT_PLUGIN(KGlobalAccelImpl)
@@ -47,7 +46,7 @@ WaylandTestApplication::WaylandTestApplication(OperationMode mode, int &argc, ch
     // TODO: add a test move to kglobalaccel instead?
     QFile{QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("kglobalshortcutsrc"))}.remove();
     QIcon::setThemeName(QStringLiteral("breeze"));
-#ifdef KWIN_BUILD_ACTIVITIES
+#if KWIN_BUILD_ACTIVITIES
     setUseKActivities(false);
 #endif
     qputenv("KWIN_COMPOSE", QByteArrayLiteral("Q"));
@@ -84,19 +83,43 @@ WaylandTestApplication::~WaylandTestApplication()
     // need to unload all effects prior to destroying X connection as they might do X calls
     // also before destroy Workspace, as effects might call into Workspace
     if (effects) {
-        static_cast<EffectsHandlerImpl*>(effects)->unloadAllEffects();
+        static_cast<EffectsHandlerImpl *>(effects)->unloadAllEffects();
     }
     delete m_xwayland;
     m_xwayland = nullptr;
+    destroyVirtualInputDevices();
     destroyWorkspace();
-    if (QStyle *s = style()) {
-        s->unpolish(this);
-    }
     destroyInputMethod();
     destroyCompositor();
     destroyInput();
 }
 
+void WaylandTestApplication::createVirtualInputDevices()
+{
+    m_virtualKeyboard.reset(new Test::VirtualInputDevice());
+    m_virtualKeyboard->setName(QStringLiteral("Virtual Keyboard 1"));
+    m_virtualKeyboard->setKeyboard(true);
+
+    m_virtualPointer.reset(new Test::VirtualInputDevice());
+    m_virtualPointer->setName(QStringLiteral("Virtual Pointer 1"));
+    m_virtualPointer->setPointer(true);
+
+    m_virtualTouch.reset(new Test::VirtualInputDevice());
+    m_virtualTouch->setName(QStringLiteral("Virtual Touch 1"));
+    m_virtualTouch->setTouch(true);
+
+    input()->addInputDevice(m_virtualPointer.get());
+    input()->addInputDevice(m_virtualTouch.get());
+    input()->addInputDevice(m_virtualKeyboard.get());
+}
+
+void WaylandTestApplication::destroyVirtualInputDevices()
+{
+    input()->removeInputDevice(m_virtualPointer.get());
+    input()->removeInputDevice(m_virtualTouch.get());
+    input()->removeInputDevice(m_virtualKeyboard.get());
+}
+
 void WaylandTestApplication::performStartup()
 {
     if (!m_inputMethodServerToStart.isEmpty()) {
@@ -118,6 +141,7 @@ void WaylandTestApplication::performStartup()
     // try creating the Wayland Backend
     createInput();
     createPlugins();
+    createVirtualInputDevices();
 
     if (!platform()->enabledOutputs().isEmpty()) {
         continueStartupWithScreens();
@@ -164,4 +188,18 @@ void WaylandTestApplication::continueStartupWithScene()
     m_xwayland->start();
 }
 
+Test::VirtualInputDevice *WaylandTestApplication::virtualPointer() const
+{
+    return m_virtualPointer.get();
+}
+
+Test::VirtualInputDevice *WaylandTestApplication::virtualKeyboard() const
+{
+    return m_virtualKeyboard.get();
+}
+
+Test::VirtualInputDevice *WaylandTestApplication::virtualTouch() const
+{
+    return m_virtualTouch.get();
+}
 }
