@@ -9,12 +9,12 @@
 #ifndef KWIN_COLORPICKER_H
 #define KWIN_COLORPICKER_H
 
-#include <kwineffects.h>
+#include <QColor>
 #include <QDBusContext>
 #include <QDBusMessage>
 #include <QDBusUnixFileDescriptor>
 #include <QObject>
-#include <QColor>
+#include <kwineffects.h>
 
 namespace KWin
 {
@@ -27,11 +27,11 @@ public:
     ColorPickerEffect();
     ~ColorPickerEffect() override;
     void paintScreen(int mask, const QRegion &region, ScreenPaintData &data) override;
-    void postPaintScreen() override;
     bool isActive() const override;
 
-    int requestedEffectChainPosition() const override {
-        return 50;
+    int requestedEffectChainPosition() const override
+    {
+        return 0;
     }
 
     static bool supported();
@@ -44,7 +44,6 @@ private:
     void hideInfoMessage();
 
     QDBusMessage m_replyMessage;
-    EffectScreen *m_paintedScreen = nullptr;
     QPoint m_scheduledPosition;
     bool m_picking = false;
 };
