@@ -7,15 +7,16 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "magiclamp_config.h"
+
+#include <config-kwin.h>
+
 // KConfigSkeleton
 #include "magiclampconfig.h"
-#include <config-kwin.h>
 
 #include <kwineffects_interface.h>
 
-#include <kconfiggroup.h>
-#include <KAboutData>
 #include <KPluginFactory>
+#include <kconfiggroup.h>
 
 #include <QVBoxLayout>
 
@@ -24,24 +25,23 @@ K_PLUGIN_CLASS(KWin::MagicLampEffectConfig)
 namespace KWin
 {
 
-MagicLampEffectConfigForm::MagicLampEffectConfigForm(QWidget* parent) : QWidget(parent)
+MagicLampEffectConfigForm::MagicLampEffectConfigForm(QWidget *parent)
+    : QWidget(parent)
 {
     setupUi(this);
 }
 
-MagicLampEffectConfig::MagicLampEffectConfig(QWidget* parent, const QVariantList& args) :
-    KCModule(parent, args)
+MagicLampEffectConfig::MagicLampEffectConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     m_ui = new MagicLampEffectConfigForm(this);
 
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     layout->addWidget(m_ui);
 
     MagicLampConfig::instance(KWIN_CONFIG);
     addConfig(MagicLampConfig::self(), m_ui);
-
-    load();
 }
 
 void MagicLampEffectConfig::save()
