@@ -1017,7 +1017,7 @@ void Workspace::initShortcuts()
     DEF2("Window Below Other Windows", kli18n("Keep Window Below Others"),
          0, slotWindowBelow);
     DEF(kli18n("Activate Window Demanding Attention"),
-        Qt::CTRL | Qt::ALT | Qt::Key_A, slotActivateAttentionWindow);
+        Qt::META | Qt::CTRL | Qt::Key_A, slotActivateAttentionWindow);
     DEF(kli18n("Setup Window Shortcut"),
         0, slotSetupWindowShortcut);
     DEF2("Window Move Center", kli18n("Move Window to the Center"), 0,
@@ -1101,7 +1101,7 @@ void Workspace::initShortcuts()
     DEF(kli18n("Switch to Next Screen"), 0, slotSwitchToNextScreen);
     DEF(kli18n("Switch to Previous Screen"), 0, slotSwitchToPrevScreen);
 
-    DEF(kli18n("Kill Window"), Qt::CTRL | Qt::ALT | Qt::Key_Escape, slotKillWindow);
+    DEF(kli18n("Kill Window"), Qt::META | Qt::CTRL | Qt::Key_Escape, slotKillWindow);
     DEF6(kli18n("Suspend Compositing"), Qt::SHIFT | Qt::ALT | Qt::Key_F12, Compositor::self(), Compositor::toggleCompositing);
     DEF6(kli18n("Invert Screen Colors"), 0, kwinApp()->platform(), Platform::invertScreen);
 
