@@ -8,22 +8,25 @@
 */
 #include "xkb.h"
 #include "utils/common.h"
+#include "wayland/keyboard_interface.h"
+#include "wayland/seat_interface.h"
 // frameworks
 #include <KConfigGroup>
-// KWayland
-#include <KWaylandServer/keyboard_interface.h>
-#include <KWaylandServer/seat_interface.h>
 // Qt
-#include <QTemporaryFile>
 #include <QKeyEvent>
+#include <QTemporaryFile>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QtXkbCommonSupport/private/qxkbcommon_p.h>
+#else
+#include <QtGui/private/qxkbcommon_p.h>
+#endif
 // xkbcommon
 #include <xkbcommon/xkbcommon-compose.h>
 #include <xkbcommon/xkbcommon-keysyms.h>
 // system
+#include <bitset>
 #include <sys/mman.h>
 #include <unistd.h>
-#include <bitset>
 
 Q_LOGGING_CATEGORY(KWIN_XKB, "kwin_xkbcommon", QtWarningMsg)
 
@@ -114,11 +117,13 @@ Xkb::~Xkb()
     xkb_context_unref(m_context);
 }
 
-void Xkb::setConfig(const KSharedConfigPtr &config) {
+void Xkb::setConfig(const KSharedConfigPtr &config)
+{
     m_configGroup = config->group("Layout");
 }
 
-void Xkb::setNumLockConfig(const KSharedConfigPtr &config) {
+void Xkb::setNumLockConfig(const KSharedConfigPtr &config)
+{
     m_numLockConfig = config;
 }
 
@@ -152,7 +157,7 @@ static bool stringIsEmptyOrNull(const char *str)
  * libxkbcommon uses secure_getenv to read the XKB_DEFAULT_* variables.
  * As kwin_wayland may have the CAP_SET_NICE capability, it returns nullptr
  * so we need to do it ourselves (see xkb_context_sanitize_rule_names).
-**/
+ **/
 void Xkb::applyEnvironmentRules(xkb_rule_names &ruleNames)
 {
     if (stringIsEmptyOrNull(ruleNames.rules)) {
@@ -216,7 +221,7 @@ void Xkb::installKeymap(int fd, uint32_t size)
     if (!m_context) {
         return;
     }
-    char *map = reinterpret_cast<char*>(mmap(nullptr, size, PROT_READ, MAP_SHARED, fd, 0));
+    char *map = reinterpret_cast<char *>(mmap(nullptr, size, PROT_READ, MAP_SHARED, fd, 0));
     if (map == MAP_FAILED) {
         return;
     }
@@ -255,16 +260,16 @@ void Xkb::updateKeymap(xkb_keymap *keymap)
     m_keymap = keymap;
     m_state = state;
 
-    m_shiftModifier   = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_SHIFT);
-    m_capsModifier    = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_CAPS);
+    m_shiftModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_SHIFT);
+    m_capsModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_CAPS);
     m_controlModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_CTRL);
-    m_altModifier     = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_ALT);
-    m_metaModifier    = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_LOGO);
-    m_numModifier     = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_NUM);
+    m_altModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_ALT);
+    m_metaModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_LOGO);
+    m_numModifier = xkb_keymap_mod_get_index(m_keymap, XKB_MOD_NAME_NUM);
 
-    m_numLock         = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_NUM);
-    m_capsLock        = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_CAPS);
-    m_scrollLock      = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_SCROLL);
+    m_numLock = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_NUM);
+    m_capsLock = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_CAPS);
+    m_scrollLock = xkb_keymap_led_get_index(m_keymap, XKB_LED_NAME_SCROLL);
 
     m_currentLayout = xkb_state_serialize_layout(m_state, XKB_STATE_LAYOUT_EFFECTIVE);
 
@@ -272,10 +277,9 @@ void Xkb::updateKeymap(xkb_keymap *keymap)
     m_modifierState.latched = xkb_state_serialize_mods(m_state, xkb_state_component(XKB_STATE_MODS_LATCHED));
     m_modifierState.locked = xkb_state_serialize_mods(m_state, xkb_state_component(XKB_STATE_MODS_LOCKED));
 
-    auto setLock = [this](xkb_mod_index_t modifier, bool value)
-    {
+    auto setLock = [this](xkb_mod_index_t modifier, bool value) {
         if (m_ownership == Ownership::Server && modifier != XKB_MOD_INVALID) {
-            std::bitset<sizeof(xkb_mod_mask_t)*8> mask{m_modifierState.locked};
+            std::bitset<sizeof(xkb_mod_mask_t) * 8> mask{m_modifierState.locked};
             if (mask.size() > modifier) {
                 mask[modifier] = value;
                 m_modifierState.locked = mask.to_ulong();
@@ -375,8 +379,7 @@ void Xkb::updateKey(uint32_t key, InputRedirection::KeyboardKeyState state)
 void Xkb::updateModifiers()
 {
     Qt::KeyboardModifiers mods = Qt::NoModifier;
-    if (xkb_state_mod_index_is_active(m_state, m_shiftModifier, XKB_STATE_MODS_EFFECTIVE) == 1 ||
-        xkb_state_mod_index_is_active(m_state, m_capsModifier, XKB_STATE_MODS_EFFECTIVE) == 1) {
+    if (xkb_state_mod_index_is_active(m_state, m_shiftModifier, XKB_STATE_MODS_EFFECTIVE) == 1 || xkb_state_mod_index_is_active(m_state, m_capsModifier, XKB_STATE_MODS_EFFECTIVE) == 1) {
         mods |= Qt::ShiftModifier;
     }
     if (xkb_state_mod_index_is_active(m_state, m_altModifier, XKB_STATE_MODS_EFFECTIVE) == 1) {
@@ -531,7 +534,7 @@ Qt::Key Xkb::toQtKey(xkb_keysym_t keySym,
                      bool superAsMeta) const
 {
     // FIXME: passing superAsMeta doesn't have impact due to bug in the Qt function, so handle it below
-    Qt::Key qtKey = Qt::Key( QXkbCommon::keysymToQtKey(keySym, modifiers, m_state, scanCode + 8, superAsMeta) );
+    Qt::Key qtKey = Qt::Key(QXkbCommon::keysymToQtKey(keySym, modifiers, m_state, scanCode + 8, superAsMeta));
 
     // FIXME: workarounds for symbols currently wrong/not mappable via keysymToQtKey()
     if (superAsMeta && (qtKey == Qt::Key_Super_L || qtKey == Qt::Key_Super_R)) {
@@ -540,7 +543,7 @@ Qt::Key Xkb::toQtKey(xkb_keysym_t keySym,
     } else if (qtKey > 0xff && keySym <= 0xff) {
         // XKB_KEY_mu, XKB_KEY_ydiaeresis go here
         qtKey = Qt::Key(keySym);
-#if QT_VERSION_MAJOR < 6	// since Qt 5 LTS is frozen
+#if QT_VERSION_MAJOR < 6 // since Qt 5 LTS is frozen
     } else if (keySym == XKB_KEY_Sys_Req) {
         // fixed in QTBUG-92087
         qtKey = Qt::Key_SysReq;
@@ -572,7 +575,7 @@ void Xkb::switchToPreviousLayout()
     if (!m_keymap || !m_state) {
         return;
     }
-    const xkb_layout_index_t previousLayout = m_currentLayout == 0 ? numberOfLayouts() - 1 : m_currentLayout -1;
+    const xkb_layout_index_t previousLayout = m_currentLayout == 0 ? numberOfLayouts() - 1 : m_currentLayout - 1;
     switchToLayout(previousLayout);
 }
 
